# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.custom_aggregations_v1_api import CustomAggregationsV1Api


class TestCustomAggregationsV1Api(unittest.TestCase):
    """CustomAggregationsV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = CustomAggregationsV1Api()

    def tearDown(self) -> None:
        pass

    def test_delete_custom_aggregation(self) -> None:
        """Test case for delete_custom_aggregation

        Delete Custom Aggregation.
        """
        pass

    def test_get_custom_aggregation(self) -> None:
        """Test case for get_custom_aggregation

        Get Custom Aggregation By Id.
        """
        pass

    def test_get_custom_aggregations_for_workspace(self) -> None:
        """Test case for get_custom_aggregations_for_workspace

        Get Custom Aggregation.
        """
        pass

    def test_patch_custom_aggregation(self) -> None:
        """Test case for patch_custom_aggregation

        Patch Custom Aggregation
        """
        pass

    def test_post_custom_aggregation(self) -> None:
        """Test case for post_custom_aggregation

        Post Custom Aggregation.
        """
        pass

    def test_put_custom_aggregation(self) -> None:
        """Test case for put_custom_aggregation

        Update Custom Aggregation By Id.
        """
        pass

    def test_validate_custom_aggregation(self) -> None:
        """Test case for validate_custom_aggregation

        Validate A Custom Aggregation Before Creation.
        """
        pass


if __name__ == '__main__':
    unittest.main()
