# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.feature_flags_v1_api import FeatureFlagsV1Api


class TestFeatureFlagsV1Api(unittest.TestCase):
    """FeatureFlagsV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = FeatureFlagsV1Api()

    def tearDown(self) -> None:
        pass

    def test_get_feature_flags(self) -> None:
        """Test case for get_feature_flags

        Get Feature Flags.
        """
        pass


if __name__ == '__main__':
    unittest.main()
